import 'dart:math';
import 'package:flutter/material.dart';
import 'package:flutter_widget_from_html/flutter_widget_from_html.dart';
import 'package:mypoint_flutter_app/screen/voucher/detail/store_list_section.dart';
import '../../../resouce/base_color.dart';
import '../../../widgets/back_button.dart';
import '../../../widgets/custom_empty_widget.dart';
import '../../../widgets/custom_price_tag.dart';
import '../../../widgets/dashed_line.dart';
import '../../../widgets/image_loader.dart';
import '../../../widgets/measure_size.dart';
import '../models/product_model.dart';
import 'voucher_detail_viewmodel.dart';
import 'package:get/get.dart';

class VoucherDetailScreen extends StatefulWidget {
  const VoucherDetailScreen({super.key});

  @override
  _VoucherDetailScreenState createState() => _VoucherDetailScreenState();
}

class _VoucherDetailScreenState extends State<VoucherDetailScreen> {
  late final int productId;
  late final VoucherDetailViewModel _viewModel;
  final GlobalKey _infoKey = GlobalKey();
  double _infoHeight = 0;

  @override
  void initState() {
    super.initState();
    final args = Get.arguments;
    if (args is int) {
      productId = args;
    } else if (args is Map) {
      productId = args['productId'];
    }
    _viewModel = Get.put(VoucherDetailViewModel(productId: productId));
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Obx(() {
        if (_viewModel.isLoading.value) {
          return const Center(child: CircularProgressIndicator());
        }
        final product = _viewModel.product.value;
        if (product == null) {
          return const Center(child: EmptyWidget());
        }
        return Stack(
          children: [
            Container(
              color: Colors.grey.shade100,
              child: SingleChildScrollView(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    _buildHeaderWithInfo(product),
                    SizedBox(height: max(_infoHeight - 36, 0)),
                    _buildDetailBlock(product),
                    _buildConditionBlock(product),
                    SizedBox(height: 8),
                    StoreListSection(stores: _viewModel.stores),
                  ],
                ),
              ),
            ),
            SafeArea(child: Padding(padding: const EdgeInsets.all(8), child: CustomBackButton())),
          ],
        );
      }),
    );
  }

  Widget _buildHeaderWithInfo(ProductModel product) {
    final double screenWidth = MediaQuery.of(context).size.width;
    final double imageHeight = screenWidth / (16 / 9);

    return Stack(
      clipBehavior: Clip.none,
      children: [
        loadNetworkImage(
          url: product.banner?.url,
          fit: BoxFit.cover,
          height: imageHeight,
          width: double.infinity,
          placeholderAsset: 'assets/images/sample.png',
        ),
        Positioned(
          left: 16,
          right: 16,
          child: MeasureSize(
            onChange: (size) {
              if (_infoHeight != size.height) {
                setState(() {
                  _infoHeight = size.height;
                });
              }
            },
            child: Transform.translate(
              offset: Offset(0, imageHeight - 36), // ✅ Lấn lên trên ảnh 36px
              child: _buildInfo(product),
            ),
          ),
        ),
      ],
    );
  }

  Widget _buildInfo(ProductModel product, {Key? key}) {
    return Container(
      key: key,
      padding: const EdgeInsets.all(16),
      decoration: BoxDecoration(
        color: Colors.white,
        borderRadius: BorderRadius.circular(16),
        boxShadow: [BoxShadow(color: Colors.black.withOpacity(0.05), blurRadius: 8, offset: const Offset(0, 4))],
      ),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          Text(product.content?.name ?? '', style: const TextStyle(fontSize: 24, fontWeight: FontWeight.bold)),
          const SizedBox(height: 8),
          _buildExpireAndStock(product),
          const SizedBox(height: 16),
          DashedLine(color: Colors.grey.shade400, dashWidth: 3, dashSpacing: 3, height: 1),
          const Divider(height: 16),
          Row(
            children: [
              CircleAvatar(
                radius: 12,
                backgroundColor: Colors.transparent,
                child: ClipOval(
                  child: loadNetworkImage(
                    url: product.brand?.logo ?? "",
                    width: 24,
                    height: 24,
                    fit: BoxFit.cover,
                    placeholderAsset: 'assets/images/ic_logo.png',
                  ),
                ),
              ),
              const SizedBox(width: 8),
              Expanded(child: Text(product.brand?.name ?? '', style: const TextStyle(fontSize: 14))),
              PriceTagWidget(point: product.amountToBePaid ?? 0),
            ],
          ),
        ],
      ),
    );
  }

  Widget _buildExpireAndStock(ProductModel product) {
    final bool isOutOfStock = !(product.inStock ?? true);
    final bool hasExpire = product.expire.isNotEmpty;

    return Row(
      mainAxisAlignment: MainAxisAlignment.center,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: [
        if (hasExpire)
          Text(
            'Hạn dùng: ',
            style: const TextStyle(
              color: Colors.grey,
              fontWeight: FontWeight.bold,
              fontSize: 12,
            ),
          ),
        if (hasExpire)
          Text(
            product.expire,
            style: const TextStyle(
              color: Colors.red,
              fontWeight: FontWeight.bold,
              fontSize: 12,
            ),
          ),
        if (isOutOfStock)
          Container(
            margin: const EdgeInsets.only(left: 8),
            padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 4),
            decoration: BoxDecoration(
              color: Colors.grey,
              borderRadius: BorderRadius.circular(4),
            ),
            child: const Text(
              'Tạm hết',
              style: TextStyle(color: Colors.white, fontSize: 12, fontWeight: FontWeight.bold),
            ),
          ),
      ],
    );
  }

  Widget _buildDetailBlock(ProductModel product) {
    return _buildTextBlock("Chi tiết ưu đãi", product.content?.detail);
  }

  Widget _buildConditionBlock(ProductModel product) {
    return _buildTextBlock("Điều kiện áp dụng", product.content?.termAndCondition);
  }

  Widget _buildTextBlock(String title, String? content) {
    if (content == null || content.isEmpty) return const SizedBox();
    return Container(
      padding: const EdgeInsets.all(16),
      margin: const EdgeInsets.only(top: 16, left: 16, right: 16, bottom: 0),
      decoration: BoxDecoration(color: Colors.white, borderRadius: BorderRadius.circular(16)),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(title, style: const TextStyle(fontSize: 16, fontWeight: FontWeight.bold)),
          const SizedBox(height: 8),
          HtmlWidget(content),
        ],
      ),
    );
  }
}
